@@ -57,10 +57,9 @@ class Reports(Client):
             kwargs.update({'reportTypes': ','.join(kwargs.get('reportTypes'))})
         if kwargs.get('processingStatuses', None) and isinstance(kwargs.get('processingStatuses'), abc.Iterable):
             kwargs.update({'processingStatuses': ','.join(kwargs.get('processingStatuses'))})
+        print(kwargs, kwargs.get('marketplaceIds'))
         if kwargs.get('marketplaceIds', None) and isinstance(kwargs.get('marketplaceIds'), abc.Iterable):
             marketplaces = kwargs.get('marketplaceIds')
-            if not isinstance(marketplaces, abc.Iterable):
-                marketplaces = [marketplaces]
             kwargs.update({'marketplaceIds': ','.join(
                 [m.marketplace_id if isinstance(m, Marketplaces) else m for m in marketplaces])})
         for k in ['createdSince', 'createdUntil']:
@@ -219,8 +218,8 @@ class Reports(Client):
             key reportType: str
             key marketplaceIds: str
             key reportOptions: dict
-            period: Schedules
-            nextReportCreationTime: str datetime isoformat
+            key period: Schedules
+            key nextReportCreationTime: str datetime isoformat
 
         Returns:
             ApiResponse:
@@ -312,7 +311,7 @@ class Reports(Client):
                 Reports().get_report_schedule('ID323')
 
         Args:
-            schedule_id: str | required The identifier for the report schedule. This identifier is unique only in combination with a seller ID.
+            reportScheduleId: str | required The identifier for the report schedule. This identifier is unique only in combination with a seller ID.
             kwargs:
 
         Returns:
